interface UrlPage_Params {
    videoUrl?: string;
    proxyUrl?: string;
    controller?: TextInputController;
    rightListener?: onRightClickListener;
}
import { HeaderComponent } from "@bundle:com.aliyun.player.ohos_demo/listapp/ets/view/HeaderComponent";
import type { onRightClickListener } from "@bundle:com.aliyun.player.ohos_demo/listapp/ets/view/HeaderComponent";
import router from "@ohos:router";
import { Hlog } from "@bundle:com.aliyun.player.ohos_demo/listapp/ets/common/util/Hlog";
import scanCore from "@hms:core.scan.scanCore";
import scanBarcode from "@hms:core.scan.scanBarcode";
import { NormalButtonComponent } from "@bundle:com.aliyun.player.ohos_demo/listapp/ets/view/NormalButtonComponent";
import { InputTextNormal } from "@bundle:com.aliyun.player.ohos_demo/listapp/ets/view/TextInputComponent";
import { showToast } from "@bundle:com.aliyun.player.ohos_demo/listapp/ets/common/util/CommonUtils";
import window from "@ohos:window";
const log: Hlog = new Hlog('PlayerPage');
class UrlPage extends ViewPU {
    constructor(parent, params, __localStorage, elmtId = -1, paramsLambda = undefined, extraInfo) {
        super(parent, __localStorage, elmtId, extraInfo);
        if (typeof paramsLambda === "function") {
            this.paramsGenerator_ = paramsLambda;
        }
        this.__videoUrl = new ObservedPropertySimplePU('http://player.alicdn.com/video/aliyunmedia.mp4', this, "videoUrl");
        this.__proxyUrl = new ObservedPropertySimplePU('https://proxy', this, "proxyUrl");
        this.controller = new TextInputController();
        this.rightListener = {
            onRightItemClick: async () => {
                // 定义扫码参数options
                let options: scanBarcode.ScanOptions = {
                    scanTypes: [scanCore.ScanType.QR_CODE],
                    enableMultiMode: true,
                    enableAlbum: true
                };
                // 启动扫码，拉起扫码界面
                let result = await scanBarcode.startScan(options);
                log.i(`startScan: ${JSON.stringify(result)}`);
                this.videoUrl = result.originalValue; // 将扫描结果填充到输入框中
                this.validateUrl();
                showToast(this.videoUrl);
            }
        };
        this.setInitiallyProvidedValue(params);
    }
    setInitiallyProvidedValue(params: UrlPage_Params) {
        if (params.videoUrl !== undefined) {
            this.videoUrl = params.videoUrl;
        }
        if (params.proxyUrl !== undefined) {
            this.proxyUrl = params.proxyUrl;
        }
        if (params.controller !== undefined) {
            this.controller = params.controller;
        }
        if (params.rightListener !== undefined) {
            this.rightListener = params.rightListener;
        }
    }
    updateStateVars(params: UrlPage_Params) {
    }
    purgeVariableDependenciesOnElmtId(rmElmtId) {
        this.__videoUrl.purgeDependencyOnElmtId(rmElmtId);
        this.__proxyUrl.purgeDependencyOnElmtId(rmElmtId);
    }
    aboutToBeDeleted() {
        this.__videoUrl.aboutToBeDeleted();
        this.__proxyUrl.aboutToBeDeleted();
        SubscriberManager.Get().delete(this.id__());
        this.aboutToBeDeletedInternal();
    }
    private __videoUrl: ObservedPropertySimplePU<string>;
    get videoUrl() {
        return this.__videoUrl.get();
    }
    set videoUrl(newValue: string) {
        this.__videoUrl.set(newValue);
    }
    private __proxyUrl: ObservedPropertySimplePU<string>;
    get proxyUrl() {
        return this.__proxyUrl.get();
    }
    set proxyUrl(newValue: string) {
        this.__proxyUrl.set(newValue);
    }
    private controller: TextInputController;
    private rightListener: onRightClickListener;
    private validateUrl() {
        if (!this.videoUrl) {
            this.videoUrl = 'http://player.alicdn.com/video/aliyunmedia.mp4';
        }
    }
    aboutToAppear(): void {
    }
    onPageShow(): void {
        window.getLastWindow(getContext(this)).then(wind => {
            wind.setWindowSystemBarEnable([]);
            setTimeout(() => {
                wind.setWindowSystemBarEnable(['status']);
            }, 400);
        });
    }
    initialRender() {
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Row.create();
            Row.height('100%');
            Row.alignItems(VerticalAlign.Top);
        }, Row);
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Column.create();
            Column.width('100%');
        }, Column);
        {
            this.observeComponentCreation2((elmtId, isInitialRender) => {
                if (isInitialRender) {
                    let paramsLambda = () => {
                        return {
                            title: '输入URL界面',
                            rightTitle: '二维码扫描',
                            rightListener: this.rightListener
                        };
                    };
                    ViewPU.create(new HeaderComponent(this, { title: '输入URL界面', rightTitle: '二维码扫描', rightListener: this.rightListener }, undefined, elmtId, paramsLambda, { page: "amdemos-player-ohos-listapp/src/main/ets/pages/UrlPage.ets", line: 56 }));
                }
                else {
                    this.updateStateVarsOfChildByElmtId(elmtId, {});
                }
            }, { name: "HeaderComponent" });
        }
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Column.create();
            Column.width('100%');
            Column.padding({ left: 16, right: 16 });
            Column.alignItems(HorizontalAlign.Start);
        }, Column);
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            __Common__.create();
            __Common__.margin({ top: 10 });
        }, __Common__);
        {
            this.observeComponentCreation2((elmtId, isInitialRender) => {
                if (isInitialRender) {
                    let paramsLambda = () => {
                        return {
                            mTitle: this.videoUrl
                        };
                    };
                    ViewPU.create(new InputTextNormal(this, { mTitle: this.__videoUrl }, undefined, elmtId, paramsLambda, { page: "amdemos-player-ohos-listapp/src/main/ets/pages/UrlPage.ets", line: 58 }));
                }
                else {
                    this.updateStateVarsOfChildByElmtId(elmtId, {});
                }
            }, { name: "InputTextNormal" });
        }
        __Common__.pop();
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            __Common__.create();
            __Common__.onClick(() => {
                this.validateUrl();
                router.pushUrl({ url: 'pages/PlayerPage', params: { videoUrl: this.videoUrl } });
            });
        }, __Common__);
        {
            this.observeComponentCreation2((elmtId, isInitialRender) => {
                if (isInitialRender) {
                    let paramsLambda = () => {
                        return {
                            mTitle: '进入阿里云播放器'
                        };
                    };
                    ViewPU.create(new NormalButtonComponent(this, { mTitle: '进入阿里云播放器' }, undefined, elmtId, paramsLambda, { page: "amdemos-player-ohos-listapp/src/main/ets/pages/UrlPage.ets", line: 61 }));
                }
                else {
                    this.updateStateVarsOfChildByElmtId(elmtId, {});
                }
            }, { name: "NormalButtonComponent" });
        }
        __Common__.pop();
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            __Common__.create();
            __Common__.onClick(() => {
                router.pushUrl({ url: 'pages/ListPlayerPage', params: { videoUrlList: [] } });
            });
        }, __Common__);
        {
            this.observeComponentCreation2((elmtId, isInitialRender) => {
                if (isInitialRender) {
                    let paramsLambda = () => {
                        return {
                            mTitle: '阿里云多实例播放器'
                        };
                    };
                    ViewPU.create(new NormalButtonComponent(this, { mTitle: '阿里云多实例播放器' }, undefined, elmtId, paramsLambda, { page: "amdemos-player-ohos-listapp/src/main/ets/pages/UrlPage.ets", line: 67 }));
                }
                else {
                    this.updateStateVarsOfChildByElmtId(elmtId, {});
                }
            }, { name: "NormalButtonComponent" });
        }
        __Common__.pop();
        this.DrmScheme.bind(this)();
        this.LicenseUrl.bind(this)();
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            __Common__.create();
            __Common__.width('50%');
        }, __Common__);
        {
            this.observeComponentCreation2((elmtId, isInitialRender) => {
                if (isInitialRender) {
                    let paramsLambda = () => {
                        return {
                            mTitle: '进入EXOPLAYER'
                        };
                    };
                    ViewPU.create(new NormalButtonComponent(this, { mTitle: '进入EXOPLAYER' }, undefined, elmtId, paramsLambda, { page: "amdemos-player-ohos-listapp/src/main/ets/pages/UrlPage.ets", line: 76 }));
                }
                else {
                    this.updateStateVarsOfChildByElmtId(elmtId, {});
                }
            }, { name: "NormalButtonComponent" });
        }
        __Common__.pop();
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            __Common__.create();
            __Common__.width('50%');
        }, __Common__);
        {
            this.observeComponentCreation2((elmtId, isInitialRender) => {
                if (isInitialRender) {
                    let paramsLambda = () => {
                        return {
                            mTitle: '进入MEDIAPLAYER'
                        };
                    };
                    ViewPU.create(new NormalButtonComponent(this, { mTitle: '进入MEDIAPLAYER' }, undefined, elmtId, paramsLambda, { page: "amdemos-player-ohos-listapp/src/main/ets/pages/UrlPage.ets", line: 77 }));
                }
                else {
                    this.updateStateVarsOfChildByElmtId(elmtId, {});
                }
            }, { name: "NormalButtonComponent" });
        }
        __Common__.pop();
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            __Common__.create();
            __Common__.width('50%');
        }, __Common__);
        {
            this.observeComponentCreation2((elmtId, isInitialRender) => {
                if (isInitialRender) {
                    let paramsLambda = () => {
                        return {
                            mTitle: '进入VRPLAYER'
                        };
                    };
                    ViewPU.create(new NormalButtonComponent(this, { mTitle: '进入VRPLAYER' }, undefined, elmtId, paramsLambda, { page: "amdemos-player-ohos-listapp/src/main/ets/pages/UrlPage.ets", line: 78 }));
                }
                else {
                    this.updateStateVarsOfChildByElmtId(elmtId, {});
                }
            }, { name: "NormalButtonComponent" });
        }
        __Common__.pop();
        Column.pop();
        Column.pop();
        Row.pop();
    }
    DrmScheme(parent = null) {
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Row.create();
            Row.width('100%');
            Row.height(56);
        }, Row);
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Text.create('DrmScheme(*)');
            Text.padding({ right: 6 });
            Text.fontColor(0xDDDDDD);
            Text.width('30%');
        }, Text);
        Text.pop();
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Row.create();
            Row.width('35%');
        }, Row);
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Radio.create({ value: '0', group: 'radioGroup' });
            Radio.checked(true);
            Radio.radioStyle({
                checkedBackgroundColor: Color.Pink
            });
        }, Radio);
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Text.create('None');
        }, Text);
        Text.pop();
        Row.pop();
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Row.create();
            Row.width('35%');
        }, Row);
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Radio.create({ value: '1', group: 'radioGroup' });
            Radio.checked(false);
            Radio.radioStyle({
                checkedBackgroundColor: Color.Pink
            });
        }, Radio);
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Text.create('WideVine');
        }, Text);
        Text.pop();
        Row.pop();
        Row.pop();
    }
    LicenseUrl(parent = null) {
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Row.create();
            Row.width('100%');
            Row.height(56);
        }, Row);
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Text.create('LicenseUrl(Optional)');
            Text.padding({ right: 6 });
            Text.fontColor(0xDDDDDD);
            Text.width('30%');
        }, Text);
        Text.pop();
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            __Common__.create();
            __Common__.width('70%');
        }, __Common__);
        {
            this.observeComponentCreation2((elmtId, isInitialRender) => {
                if (isInitialRender) {
                    let paramsLambda = () => {
                        return {
                            mTitle: this.proxyUrl
                        };
                    };
                    ViewPU.create(new InputTextNormal(this, { mTitle: this.__proxyUrl }, undefined, elmtId, paramsLambda, { page: "amdemos-player-ohos-listapp/src/main/ets/pages/UrlPage.ets", line: 111 }));
                }
                else {
                    this.updateStateVarsOfChildByElmtId(elmtId, {});
                }
            }, { name: "InputTextNormal" });
        }
        __Common__.pop();
        Row.pop();
    }
    rerender() {
        this.updateDirtyElements();
    }
    static getEntryName(): string {
        return "UrlPage";
    }
}
registerNamedRoute(() => new UrlPage(undefined, {}), "", { bundleName: "com.aliyun.player.ohos_demo", moduleName: "listapp", pagePath: "pages/UrlPage" });
