interface VideoComponent_Params {
    videoUrl?: string;
    videoProgress?: number;
    buffer?: string;
    bufferedProgress?: number;
    _enableHardwareDecode?: boolean;
    mDuration?: string;
    surfaceId?: string;
    playerIndex?: number;
    isFullScreen?: boolean;
    _forceHeight?: number;
    showFinishScene?: boolean;
    showLoadingScene?: boolean;
    showBrightnessScene?: boolean;
    showVolumeScene?: boolean;
    potentialScene?: TIP_MODE | undefined;
    loadingProgress?: number;
    loadingSpeed?: number;
    replaying?: boolean;
    isError?: boolean;
    errInfo?: ErrorInfo | undefined;
    seekType?: SEEK_TYPE;
    xComponentController?;
    mVideoDuration?: number;
    updateBufferTimer?: number | null;
    currentBrightness?: number;
    displayBrightness?: number;
    storedVolume?: number;
    currentVolume?: number;
    displayVolume?: number;
    isLive?: boolean;
    autoRotateResetTimer?: number | null;
    mPrepared?: OnPreparedListener;
    mOnCompletion?: OnCompletionListener;
    mOnFirstFrame?: OnRenderingStartListener;
    mOnVideoInfo?: OnInfoListener;
    mOnStatusChangedListener?: OnStateChangedListener;
    mOnErrorEventListener?: OnErrorListener;
    mOnLoadingProgressEventListener?: OnLoadingStatusListener;
    mSwitchedToSoftListener?: OnSwitchedToSoftListener;
    mFullscreenListener?: OnFullscreenToggleListener;
}
import type { UrlPlayer } from 'premierlibrary';
import type { OnCompletionListener, OnInfoListener, OnPreparedListener, OnRenderingStartListener, OnStateChangedListener, OnErrorListener, OnLoadingStatusListener } from 'premierlibrary/src/main/ets/com/aliyun/player/IPlayer';
import { UrlSource } from "@package:pkg_modules/.ohpm/premierlibrary@donfdoen1mcr6ssy+rjg6ltkuce=/pkg_modules/premierlibrary/src/main/ets/com/aliyun/player/source/UrlSource";
import { LOCAL_PROP_KEY_DURATION, LOCAL_PROP_KEY_HARDWARE_DECODE_ENABLED, LOCAL_PROP_KEY_VOLUME, SEEK_TYPE, TIP_MODE } from "@bundle:com.aliyun.player.ohos_demo/listapp/ets/common/Constants";
import { CommonUtils } from "@bundle:com.aliyun.player.ohos_demo/listapp/ets/common/util/CommonUtils";
import { Hlog } from "@bundle:com.aliyun.player.ohos_demo/listapp/ets/common/util/Hlog";
import VideoController from "@bundle:com.aliyun.player.ohos_demo/listapp/ets/controller/VideoController";
import { showToast } from "@bundle:com.aliyun.player.ohos_demo/listapp/ets/common/util/CommonUtils";
import type { OnFullscreenToggleListener, OnSwitchedToSoftListener } from '../pages/PlayerPage';
import type { InfoBean } from 'premierlibrary/src/main/ets/com/aliyun/player/bean/InfoBean';
import { InfoCode } from "@package:pkg_modules/.ohpm/premierlibrary@donfdoen1mcr6ssy+rjg6ltkuce=/pkg_modules/premierlibrary/src/main/ets/com/aliyun/player/bean/InfoCode";
import type { ErrorInfo } from 'premierlibrary/src/main/ets/com/aliyun/player/bean/ErrorInfo';
import window from "@ohos:window";
import type { BusinessError } from "@ohos:base";
const log: Hlog = new Hlog('VideaComponent');
export class VideoComponent extends ViewPU {
    constructor(parent, params, __localStorage, elmtId = -1, paramsLambda = undefined, extraInfo) {
        super(parent, __localStorage, elmtId, extraInfo);
        if (typeof paramsLambda === "function") {
            this.paramsGenerator_ = paramsLambda;
        }
        this.__videoUrl = new ObservedPropertySimplePU('', this, "videoUrl");
        this.__videoProgress = new ObservedPropertySimplePU(0, this, "videoProgress");
        this.__buffer = new ObservedPropertySimplePU('00:00', this, "buffer");
        this.__bufferedProgress = new ObservedPropertySimplePU(0, this, "bufferedProgress");
        this.___enableHardwareDecode = this.createStorageProp(LOCAL_PROP_KEY_HARDWARE_DECODE_ENABLED, false, "_enableHardwareDecode");
        this.__mDuration = new ObservedPropertySimplePU('00:00/00:00', this, "mDuration");
        this.__surfaceId = new SynchedPropertySimpleOneWayPU(params.surfaceId, this, "surfaceId");
        this.__playerIndex = new SynchedPropertySimpleOneWayPU(params.playerIndex, this, "playerIndex");
        this.__isFullScreen = new SynchedPropertySimpleTwoWayPU(params.isFullScreen, this, "isFullScreen");
        this.___forceHeight = new SynchedPropertySimpleOneWayPU(params._forceHeight, this, "_forceHeight");
        this.__showFinishScene = new SynchedPropertySimpleTwoWayPU(params.showFinishScene, this, "showFinishScene");
        this.__showLoadingScene = new SynchedPropertySimpleTwoWayPU(params.showLoadingScene, this, "showLoadingScene");
        this.__showBrightnessScene = new ObservedPropertySimplePU(false, this, "showBrightnessScene");
        this.__showVolumeScene = new ObservedPropertySimplePU(false, this, "showVolumeScene");
        this.__potentialScene = new ObservedPropertySimplePU(undefined, this, "potentialScene");
        this.__loadingProgress = new ObservedPropertySimplePU(0, this, "loadingProgress");
        this.__loadingSpeed = new ObservedPropertySimplePU(0, this, "loadingSpeed");
        this.__replaying = new ObservedPropertySimplePU(false, this, "replaying");
        this.__isError = new ObservedPropertySimplePU(false, this, "isError");
        this.__errInfo = new ObservedPropertyObjectPU(undefined, this, "errInfo");
        this.__seekType = new SynchedPropertySimpleTwoWayPU(params.seekType, this, "seekType");
        this.xComponentController = new XComponentController();
        this.mVideoDuration = 0;
        this.updateBufferTimer = null;
        this.currentBrightness = 0.5;
        this.__displayBrightness = new ObservedPropertySimplePU(0.5, this, "displayBrightness");
        this.__storedVolume = this.createStorageProp(LOCAL_PROP_KEY_VOLUME, 50, "storedVolume");
        this.currentVolume = 50;
        this.__displayVolume = new ObservedPropertySimplePU(0.5, this, "displayVolume");
        this.__isLive = new ObservedPropertySimplePU(false, this, "isLive");
        this.autoRotateResetTimer = null;
        this.mPrepared = {
            onPrepared: () => {
                let player: UrlPlayer = VideoController.getPlayer(this.playerIndex) as UrlPlayer;
                showToast("CALLBACK: onPrepared " + this.playerIndex);
                // 初始化完成的回调 1、存音量，2、存视频时长
                let volume: number = player.getVolume();
                this.currentVolume = volume * 50;
                this.displayVolume = volume / 2;
                AppStorage.setOrCreate<number>(LOCAL_PROP_KEY_VOLUME, volume * 50);
                AppStorage.setOrCreate<string>(LOCAL_PROP_KEY_DURATION, this.getDurationString(player.getDuration(), player
                    .getCurrentPosition()));
                this.mVideoDuration = player.getDuration();
                this.isLive = this.mVideoDuration === 0;
                console.log("[HOS DEMO] [PREPARED]", `player index: ${this.playerIndex}| duration: ${this.mVideoDuration}| volume: ${volume}`);
                if (this.replaying) {
                    player.start();
                    this.replaying = false;
                }
            }
        };
        this.mOnCompletion = {
            onCompletion: () => {
                console.log("[HOS DEMO] [COMPLETION]");
                showToast("CALLBACK: onCompletion");
                this.showFinishScene = true;
            }
        };
        this.mOnFirstFrame = {
            onRenderingStart: () => {
                console.log("[HOS DEMO] [FIRST FRAME]");
                showToast("CALLBACK: onFirstFrame");
            }
        };
        this.mOnVideoInfo = {
            onInfo: (bean: InfoBean) => {
                if (bean.getCode() === InfoCode.CurrentPosition) {
                    this.videoProgress = bean.getExtraValue() / this.mVideoDuration * 100;
                    this.mDuration = this.getDurationString(this.mVideoDuration, bean.getExtraValue());
                }
                else if (bean.getCode() === InfoCode.BufferedPosition) {
                    this.buffer = CommonUtils.secondToTime(Math.floor(bean.getExtraValue() / 1000));
                    this.bufferedProgress = bean.getExtraValue() / this.mVideoDuration * 100;
                }
                else if (bean.getCode() === InfoCode.SwitchToSoftwareVideoDecoder) {
                    console.log("[HOS DEMO] [DOWNGRADE TO SOFTWARE DECODE]");
                    this.mSwitchedToSoftListener?.onSwitched();
                }
            }
        };
        this.mOnStatusChangedListener = {
            onStateChanged: (status: number) => {
                log.i("Status Changed");
                let toastStatus: string = "";
                switch (status) {
                    case -1:
                        toastStatus = "未知";
                        break;
                    case 0:
                        toastStatus = "空状态";
                        break;
                    case 1:
                        toastStatus = "初始化";
                        break;
                    case 2:
                        toastStatus = "准备成功";
                        break;
                    case 3:
                        toastStatus = "正在播放";
                        break;
                    case 4:
                        toastStatus = "已暂停";
                        break;
                    case 5:
                        toastStatus = "已停止";
                        break;
                    case 6:
                        toastStatus = "播放完成";
                        break;
                    case 7:
                        toastStatus = "播放出错";
                        break;
                    default:
                        toastStatus = "未知";
                        break;
                }
                showToast("状态: " + toastStatus);
            }
        };
        this.mOnErrorEventListener = {
            onError: (errorInfo) => {
                this.errInfo = errorInfo;
                this.showFinishScene = true;
                this.isError = true;
            }
        };
        this.mOnLoadingProgressEventListener = {
            onLoadingBegin: () => {
                showToast("loading");
                console.log("[HOS DEMO] [LOADING START]");
                this.showLoadingScene = true;
            },
            onLoadingProgress: (percent: number, netSpeed: number) => {
                this.loadingProgress = percent;
                this.loadingSpeed = netSpeed;
            },
            onLoadingEnd: () => {
                showToast("loading complete");
                console.log("[HOS DEMO] [LOADING DONE]");
                this.showLoadingScene = false;
                this.loadingProgress = 0;
                this.loadingSpeed = 0;
            }
        };
        this.mSwitchedToSoftListener = undefined;
        this.mFullscreenListener = undefined;
        this.setInitiallyProvidedValue(params);
    }
    setInitiallyProvidedValue(params: VideoComponent_Params) {
        if (params.videoUrl !== undefined) {
            this.videoUrl = params.videoUrl;
        }
        if (params.videoProgress !== undefined) {
            this.videoProgress = params.videoProgress;
        }
        if (params.buffer !== undefined) {
            this.buffer = params.buffer;
        }
        if (params.bufferedProgress !== undefined) {
            this.bufferedProgress = params.bufferedProgress;
        }
        if (params.mDuration !== undefined) {
            this.mDuration = params.mDuration;
        }
        if (params.surfaceId === undefined) {
            this.__surfaceId.set('');
        }
        if (params.playerIndex === undefined) {
            this.__playerIndex.set(-1);
        }
        if (params._forceHeight === undefined) {
            this.___forceHeight.set(-1);
        }
        if (params.showBrightnessScene !== undefined) {
            this.showBrightnessScene = params.showBrightnessScene;
        }
        if (params.showVolumeScene !== undefined) {
            this.showVolumeScene = params.showVolumeScene;
        }
        if (params.potentialScene !== undefined) {
            this.potentialScene = params.potentialScene;
        }
        if (params.loadingProgress !== undefined) {
            this.loadingProgress = params.loadingProgress;
        }
        if (params.loadingSpeed !== undefined) {
            this.loadingSpeed = params.loadingSpeed;
        }
        if (params.replaying !== undefined) {
            this.replaying = params.replaying;
        }
        if (params.isError !== undefined) {
            this.isError = params.isError;
        }
        if (params.errInfo !== undefined) {
            this.errInfo = params.errInfo;
        }
        if (params.xComponentController !== undefined) {
            this.xComponentController = params.xComponentController;
        }
        if (params.mVideoDuration !== undefined) {
            this.mVideoDuration = params.mVideoDuration;
        }
        if (params.updateBufferTimer !== undefined) {
            this.updateBufferTimer = params.updateBufferTimer;
        }
        if (params.currentBrightness !== undefined) {
            this.currentBrightness = params.currentBrightness;
        }
        if (params.displayBrightness !== undefined) {
            this.displayBrightness = params.displayBrightness;
        }
        if (params.currentVolume !== undefined) {
            this.currentVolume = params.currentVolume;
        }
        if (params.displayVolume !== undefined) {
            this.displayVolume = params.displayVolume;
        }
        if (params.isLive !== undefined) {
            this.isLive = params.isLive;
        }
        if (params.autoRotateResetTimer !== undefined) {
            this.autoRotateResetTimer = params.autoRotateResetTimer;
        }
        if (params.mPrepared !== undefined) {
            this.mPrepared = params.mPrepared;
        }
        if (params.mOnCompletion !== undefined) {
            this.mOnCompletion = params.mOnCompletion;
        }
        if (params.mOnFirstFrame !== undefined) {
            this.mOnFirstFrame = params.mOnFirstFrame;
        }
        if (params.mOnVideoInfo !== undefined) {
            this.mOnVideoInfo = params.mOnVideoInfo;
        }
        if (params.mOnStatusChangedListener !== undefined) {
            this.mOnStatusChangedListener = params.mOnStatusChangedListener;
        }
        if (params.mOnErrorEventListener !== undefined) {
            this.mOnErrorEventListener = params.mOnErrorEventListener;
        }
        if (params.mOnLoadingProgressEventListener !== undefined) {
            this.mOnLoadingProgressEventListener = params.mOnLoadingProgressEventListener;
        }
        if (params.mSwitchedToSoftListener !== undefined) {
            this.mSwitchedToSoftListener = params.mSwitchedToSoftListener;
        }
        if (params.mFullscreenListener !== undefined) {
            this.mFullscreenListener = params.mFullscreenListener;
        }
    }
    updateStateVars(params: VideoComponent_Params) {
        this.__surfaceId.reset(params.surfaceId);
        this.__playerIndex.reset(params.playerIndex);
        this.___forceHeight.reset(params._forceHeight);
    }
    purgeVariableDependenciesOnElmtId(rmElmtId) {
        this.__videoUrl.purgeDependencyOnElmtId(rmElmtId);
        this.__videoProgress.purgeDependencyOnElmtId(rmElmtId);
        this.__buffer.purgeDependencyOnElmtId(rmElmtId);
        this.__bufferedProgress.purgeDependencyOnElmtId(rmElmtId);
        this.___enableHardwareDecode.purgeDependencyOnElmtId(rmElmtId);
        this.__mDuration.purgeDependencyOnElmtId(rmElmtId);
        this.__surfaceId.purgeDependencyOnElmtId(rmElmtId);
        this.__playerIndex.purgeDependencyOnElmtId(rmElmtId);
        this.__isFullScreen.purgeDependencyOnElmtId(rmElmtId);
        this.___forceHeight.purgeDependencyOnElmtId(rmElmtId);
        this.__showFinishScene.purgeDependencyOnElmtId(rmElmtId);
        this.__showLoadingScene.purgeDependencyOnElmtId(rmElmtId);
        this.__showBrightnessScene.purgeDependencyOnElmtId(rmElmtId);
        this.__showVolumeScene.purgeDependencyOnElmtId(rmElmtId);
        this.__potentialScene.purgeDependencyOnElmtId(rmElmtId);
        this.__loadingProgress.purgeDependencyOnElmtId(rmElmtId);
        this.__loadingSpeed.purgeDependencyOnElmtId(rmElmtId);
        this.__replaying.purgeDependencyOnElmtId(rmElmtId);
        this.__isError.purgeDependencyOnElmtId(rmElmtId);
        this.__errInfo.purgeDependencyOnElmtId(rmElmtId);
        this.__seekType.purgeDependencyOnElmtId(rmElmtId);
        this.__displayBrightness.purgeDependencyOnElmtId(rmElmtId);
        this.__storedVolume.purgeDependencyOnElmtId(rmElmtId);
        this.__displayVolume.purgeDependencyOnElmtId(rmElmtId);
        this.__isLive.purgeDependencyOnElmtId(rmElmtId);
    }
    aboutToBeDeleted() {
        this.__videoUrl.aboutToBeDeleted();
        this.__videoProgress.aboutToBeDeleted();
        this.__buffer.aboutToBeDeleted();
        this.__bufferedProgress.aboutToBeDeleted();
        this.___enableHardwareDecode.aboutToBeDeleted();
        this.__mDuration.aboutToBeDeleted();
        this.__surfaceId.aboutToBeDeleted();
        this.__playerIndex.aboutToBeDeleted();
        this.__isFullScreen.aboutToBeDeleted();
        this.___forceHeight.aboutToBeDeleted();
        this.__showFinishScene.aboutToBeDeleted();
        this.__showLoadingScene.aboutToBeDeleted();
        this.__showBrightnessScene.aboutToBeDeleted();
        this.__showVolumeScene.aboutToBeDeleted();
        this.__potentialScene.aboutToBeDeleted();
        this.__loadingProgress.aboutToBeDeleted();
        this.__loadingSpeed.aboutToBeDeleted();
        this.__replaying.aboutToBeDeleted();
        this.__isError.aboutToBeDeleted();
        this.__errInfo.aboutToBeDeleted();
        this.__seekType.aboutToBeDeleted();
        this.__displayBrightness.aboutToBeDeleted();
        this.__storedVolume.aboutToBeDeleted();
        this.__displayVolume.aboutToBeDeleted();
        this.__isLive.aboutToBeDeleted();
        SubscriberManager.Get().delete(this.id__());
        this.aboutToBeDeletedInternal();
    }
    private __videoUrl: ObservedPropertySimplePU<string>;
    get videoUrl() {
        return this.__videoUrl.get();
    }
    set videoUrl(newValue: string) {
        this.__videoUrl.set(newValue);
    }
    private __videoProgress: ObservedPropertySimplePU<number>;
    get videoProgress() {
        return this.__videoProgress.get();
    }
    set videoProgress(newValue: number) {
        this.__videoProgress.set(newValue);
    }
    private __buffer: ObservedPropertySimplePU<string>;
    get buffer() {
        return this.__buffer.get();
    }
    set buffer(newValue: string) {
        this.__buffer.set(newValue);
    }
    private __bufferedProgress: ObservedPropertySimplePU<number>;
    get bufferedProgress() {
        return this.__bufferedProgress.get();
    }
    set bufferedProgress(newValue: number) {
        this.__bufferedProgress.set(newValue);
    }
    // @StorageProp(LOCAL_PROP_KEY_DURATION) mDuration: string = '00:00/00:00';
    private ___enableHardwareDecode: ObservedPropertyAbstractPU<boolean>;
    get _enableHardwareDecode() {
        return this.___enableHardwareDecode.get();
    }
    set _enableHardwareDecode(newValue: boolean) {
        this.___enableHardwareDecode.set(newValue);
    }
    private __mDuration: ObservedPropertySimplePU<string>;
    get mDuration() {
        return this.__mDuration.get();
    }
    set mDuration(newValue: string) {
        this.__mDuration.set(newValue);
    }
    private __surfaceId: SynchedPropertySimpleOneWayPU<string>;
    get surfaceId() {
        return this.__surfaceId.get();
    }
    set surfaceId(newValue: string) {
        this.__surfaceId.set(newValue);
    }
    private __playerIndex: SynchedPropertySimpleOneWayPU<number>; // 创建播放器时会返回唯一id， 用于向VideoController索引AliPlayer
    get playerIndex() {
        return this.__playerIndex.get();
    }
    set playerIndex(newValue: number) {
        this.__playerIndex.set(newValue);
    }
    private __isFullScreen: SynchedPropertySimpleTwoWayPU<boolean>;
    get isFullScreen() {
        return this.__isFullScreen.get();
    }
    set isFullScreen(newValue: boolean) {
        this.__isFullScreen.set(newValue);
    }
    private ___forceHeight: SynchedPropertySimpleOneWayPU<number>;
    get _forceHeight() {
        return this.___forceHeight.get();
    }
    set _forceHeight(newValue: number) {
        this.___forceHeight.set(newValue);
    }
    private __showFinishScene: SynchedPropertySimpleTwoWayPU<boolean>;
    get showFinishScene() {
        return this.__showFinishScene.get();
    }
    set showFinishScene(newValue: boolean) {
        this.__showFinishScene.set(newValue);
    }
    private __showLoadingScene: SynchedPropertySimpleTwoWayPU<boolean>;
    get showLoadingScene() {
        return this.__showLoadingScene.get();
    }
    set showLoadingScene(newValue: boolean) {
        this.__showLoadingScene.set(newValue);
    }
    private __showBrightnessScene: ObservedPropertySimplePU<boolean>;
    get showBrightnessScene() {
        return this.__showBrightnessScene.get();
    }
    set showBrightnessScene(newValue: boolean) {
        this.__showBrightnessScene.set(newValue);
    }
    private __showVolumeScene: ObservedPropertySimplePU<boolean>;
    get showVolumeScene() {
        return this.__showVolumeScene.get();
    }
    set showVolumeScene(newValue: boolean) {
        this.__showVolumeScene.set(newValue);
    }
    private __potentialScene: ObservedPropertySimplePU<TIP_MODE | undefined>;
    get potentialScene() {
        return this.__potentialScene.get();
    }
    set potentialScene(newValue: TIP_MODE | undefined) {
        this.__potentialScene.set(newValue);
    }
    private __loadingProgress: ObservedPropertySimplePU<number>;
    get loadingProgress() {
        return this.__loadingProgress.get();
    }
    set loadingProgress(newValue: number) {
        this.__loadingProgress.set(newValue);
    }
    private __loadingSpeed: ObservedPropertySimplePU<number>;
    get loadingSpeed() {
        return this.__loadingSpeed.get();
    }
    set loadingSpeed(newValue: number) {
        this.__loadingSpeed.set(newValue);
    }
    private __replaying: ObservedPropertySimplePU<boolean>;
    get replaying() {
        return this.__replaying.get();
    }
    set replaying(newValue: boolean) {
        this.__replaying.set(newValue);
    }
    private __isError: ObservedPropertySimplePU<boolean>;
    get isError() {
        return this.__isError.get();
    }
    set isError(newValue: boolean) {
        this.__isError.set(newValue);
    }
    private __errInfo: ObservedPropertyObjectPU<ErrorInfo | undefined>;
    get errInfo() {
        return this.__errInfo.get();
    }
    set errInfo(newValue: ErrorInfo | undefined) {
        this.__errInfo.set(newValue);
    }
    private __seekType: SynchedPropertySimpleTwoWayPU<SEEK_TYPE>;
    get seekType() {
        return this.__seekType.get();
    }
    set seekType(newValue: SEEK_TYPE) {
        this.__seekType.set(newValue);
    }
    private xComponentController;
    /*private surfaceID: string = '';*/
    private mVideoDuration: number;
    private updateBufferTimer: number | null;
    private currentBrightness: number;
    private __displayBrightness: ObservedPropertySimplePU<number>;
    get displayBrightness() {
        return this.__displayBrightness.get();
    }
    set displayBrightness(newValue: number) {
        this.__displayBrightness.set(newValue);
    }
    private __storedVolume: ObservedPropertyAbstractPU<number>;
    get storedVolume() {
        return this.__storedVolume.get();
    }
    set storedVolume(newValue: number) {
        this.__storedVolume.set(newValue);
    }
    private currentVolume: number;
    private __displayVolume: ObservedPropertySimplePU<number>;
    get displayVolume() {
        return this.__displayVolume.get();
    }
    set displayVolume(newValue: number) {
        this.__displayVolume.set(newValue);
    }
    private __isLive: ObservedPropertySimplePU<boolean>;
    get isLive() {
        return this.__isLive.get();
    }
    set isLive(newValue: boolean) {
        this.__isLive.set(newValue);
    }
    private autoRotateResetTimer: number | null;
    private mPrepared: OnPreparedListener;
    private startBufferUpdater() {
        if (this.updateBufferTimer !== null) {
            clearInterval(this.updateBufferTimer);
        }
        this.updateBufferTimer = setInterval(() => {
            const buffered = VideoController.getPlayer(this.playerIndex)?.getBufferedPosition();
            if (buffered) {
                this.buffer = CommonUtils.secondToTime(Math.floor(buffered / 1000));
            }
        }, 500);
    }
    private stopBufferUpdater() {
        if (this.updateBufferTimer !== null) {
            clearInterval(this.updateBufferTimer);
        }
        this.updateBufferTimer = null;
    }
    private mOnCompletion: OnCompletionListener;
    private mOnFirstFrame: OnRenderingStartListener;
    private mOnVideoInfo: OnInfoListener;
    private mOnStatusChangedListener: OnStateChangedListener;
    private mOnErrorEventListener: OnErrorListener;
    private mOnLoadingProgressEventListener: OnLoadingStatusListener;
    private mSwitchedToSoftListener?: OnSwitchedToSoftListener;
    private mFullscreenListener?: OnFullscreenToggleListener;
    private getDurationString(duration: number, currentDuration: number) {
        let durationString: string = CommonUtils.secondToTime(Math.floor(duration / 1000));
        let currentDurationString: string = CommonUtils.secondToTime(Math.floor(currentDuration / 1000));
        return `${currentDurationString}/${durationString}`;
    }
    private updateBrightness(newBrightness: number) {
        window.getLastWindow(getContext(this)).then(wind => {
            wind.setWindowBrightness(newBrightness).then((res) => {
                this.displayBrightness = newBrightness;
                // showToast("brightness" + newBrightness);
                console.log("[HOS DEMO] set brightness success", newBrightness);
            }).catch((error: BusinessError) => {
                console.log("[HOS DEMO] set brightness error", error);
            });
        });
    }
    private updateVolume(newVolume: number) {
        VideoController.getPlayer(this.playerIndex)?.setVolume(newVolume);
        this.displayVolume = newVolume / 2;
        AppStorage.setOrCreate<number>(LOCAL_PROP_KEY_VOLUME, newVolume * 50);
    }
    initialRender() {
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Stack.create({ alignContent: Alignment.BottomStart });
            Stack.width('100%');
            Stack.height(this.isFullScreen ? '100%' : 200);
            Stack.backgroundColor('#00ff00');
            Stack.onTouch((event: TouchEvent) => {
                showToast(this.potentialScene + ' ' + this.isFullScreen);
                if (event) {
                    if (event.type === TouchType.Down) {
                        if (this.showBrightnessScene || this.showVolumeScene) {
                            return; // 已有手势 忽略新手势
                        }
                        if (event.changedTouches[0].x < (event.target.area.width as number) / 2) {
                            // 左半边屏幕 亮度
                            this.potentialScene = TIP_MODE.BRIGHTNESS;
                        }
                        else { // 音量
                            this.potentialScene = TIP_MODE.VOLUME;
                        }
                    }
                    else if (event.type === TouchType.Move) {
                    }
                    else if (event.type === TouchType.Up) {
                        this.potentialScene = undefined;
                    }
                }
            });
        }, Stack);
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            XComponent.create({
                id: this.playerIndex.toString(),
                type: XComponentType.SURFACE,
                libraryname: 'premierlibrary',
                controller: this.xComponentController
            }, "com.aliyun.player.ohos_demo/listapp");
            XComponent.onLoad(async () => {
                this.xComponentController.setXComponentSurfaceSize({
                    surfaceWidth: this.isFullScreen ? 3470 : 1080,
                    surfaceHeight: this.isFullScreen ? 1080 : 200
                });
                // this.surfaceID = this.xComponentController.getXComponentSurfaceId();
                log.i('onLoad: ' + this.videoUrl);
                /*
                this.videoController.createAliPlayer(getContext(), null);
                this.videoController.getPlayer()?.setSurfaceId(this.surfaceId);
                this.videoController.getPlayer()?.setAutoPlay(true);
                * */
                let player = VideoController.getPlayer(this.playerIndex);
                if (!player)
                    console.log("[HOS DEMO] VIDEO COMPONENT: ", "XC get player failed. [index]: ", this.playerIndex);
                if (player) {
                    player.setOnPreparedListener(this.mPrepared);
                    player.setOnPreparedListener(this.mPrepared);
                    player.setOnRenderingStartListener(this.mOnFirstFrame);
                    player.setOnCompletionListener(this.mOnCompletion);
                    player.setOnInfoListener(this.mOnVideoInfo);
                    player.setOnStateChangedListener(this.mOnStatusChangedListener);
                    player.setOnErrorListener(this.mOnErrorEventListener);
                    player.setOnLoadingStatusListener(this.mOnLoadingProgressEventListener);
                    !this._enableHardwareDecode && player.enableHardwareDecoder(false);
                    console.log("[HOS DEMO] VIDEO COMPONENT: ", "set surfaceId: ", this.playerIndex.toString());
                    let urlSource: UrlSource = new UrlSource();
                    urlSource.setUri(this.videoUrl);
                    VideoController.getPlayer(this.playerIndex)?.setUrlDataSource(urlSource);
                    player.setSurfaceId(this.playerIndex.toString());
                }
            });
            XComponent.width('100%');
            XComponent.height(this.isFullScreen ? '100%' : 200);
            Gesture.create(GesturePriority.Low);
            PanGesture.create({ direction: PanDirection.Vertical });
            PanGesture.onActionStart((event?: GestureEvent) => {
                switch (this.potentialScene) {
                    case TIP_MODE.VOLUME:
                        this.showVolumeScene = true;
                        break;
                    case TIP_MODE.BRIGHTNESS:
                        this.showBrightnessScene = true;
                        window.getLastWindow(getContext(this)).then(wind => {
                            const windowBrightness = wind.getWindowProperties().brightness;
                            this.currentBrightness = windowBrightness;
                            if (windowBrightness === -1) { // -1 表示跟随系统亮度 实际亮度未知 设置默认0.5
                                this.currentBrightness = 0.5;
                            }
                        });
                        break;
                }
            });
            PanGesture.onActionUpdate((event?: GestureEvent) => {
                // showToast('' + event?.offsetY);
                const offset = event ? -event.offsetY : 0;
                if (this.showBrightnessScene) {
                    let newBrightness = this.currentBrightness + (offset / 100);
                    if (newBrightness <= 0) {
                        newBrightness = 0;
                    }
                    if (newBrightness >= 1) {
                        newBrightness = 1;
                    }
                    this.updateBrightness(newBrightness);
                }
                else if (this.showVolumeScene) {
                    let newVolume = (this.currentVolume / 50) + (offset / 100);
                    if (newVolume <= 0) {
                        newVolume = 0;
                    }
                    if (newVolume >= 2) { // 最大音量 200%
                        newVolume = 2;
                    }
                    this.updateVolume(newVolume);
                }
            });
            PanGesture.onActionEnd(() => {
                // sync brightness
                this.showBrightnessScene = false;
                window.getLastWindow(getContext(this)).then(wind => {
                    const windowBrightness = wind.getWindowProperties().brightness;
                    this.currentBrightness = windowBrightness;
                    if (windowBrightness === -1) { // -1 表示跟随系统亮度 实际亮度未知 设置默认0.5
                        this.currentBrightness = 0.5;
                    }
                });
                this.displayBrightness = this.currentBrightness;
                // sync volume
                this.showVolumeScene = false;
                this.currentVolume = this.storedVolume;
                showToast("stored current" + this.currentVolume);
                this.displayVolume = this.currentVolume / 100;
            });
            PanGesture.pop();
            Gesture.pop();
        }, XComponent);
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Column.create();
            Column.width('90%');
            Column.alignItems(HorizontalAlign.Start);
            Column.margin({ left: '5%', right: '5%' });
        }, Column);
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Row.create();
            Row.width('100%');
            Row.justifyContent(FlexAlign.Center);
            Row.alignItems(VerticalAlign.Center);
            Row.onTouch((event: TouchEvent) => {
                showToast('buffer touched');
            });
        }, Row);
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Text.create("buffer:" + this.buffer);
            Text.fontSize(10);
            Text.margin({ right: '80%' });
            Text.fontColor('#FFFFFF');
        }, Text);
        Text.pop();
        Row.pop();
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Row.create();
            Row.width('100%');
            Row.justifyContent(FlexAlign.Center);
            Row.alignItems(VerticalAlign.Center);
        }, Row);
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Text.create(this.mDuration);
            Text.fontSize(10);
            Text.fontColor('#ffffff');
            Text.width('20%');
            Text.textAlign(TextAlign.Center);
        }, Text);
        Text.pop();
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Stack.create({ alignContent: Alignment.Start });
            Stack.width('70%');
        }, Stack);
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Slider.create({ value: this.videoProgress, min: 0, max: 100, style: SliderStyle.OutSet });
            Slider.showTips(true);
            Slider.onChange((value: number, mode: SliderChangeMode) => {
                this.videoProgress = value;
                if (mode === SliderChangeMode.End || mode === SliderChangeMode.Click) {
                    if (this.mVideoDuration <= 0) {
                        return;
                    }
                    this.showFinishScene = false;
                    let seekValue: number = Math.floor(this.mVideoDuration / 100 * value);
                    log.d(`seekto ${seekValue}`);
                    VideoController.getPlayer(this.playerIndex)?.seekTo(seekValue, this.seekType);
                    showToast(this.seekType === SEEK_TYPE.ACCURATE ? "精准seek" : "普通seek");
                }
            });
            Slider.width('100%');
            Slider.enabled(!this.isLive);
        }, Slider);
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Column.create();
            Column.margin({ left: '3%', right: '3%' });
            Column.width('94%');
            Column.alignItems(HorizontalAlign.Start);
        }, Column);
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Divider.create();
            Divider.vertical(false);
            Divider.strokeWidth(4);
            Divider.color('#CCCCCC');
            Divider.width('100%');
            Divider.margin({ left: `${this.videoProgress}%` });
            Divider.width(`${this.bufferedProgress - this.videoProgress}%`);
        }, Divider);
        Column.pop();
        Stack.pop();
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Text.create(this.isFullScreen ? "退出" : "全屏");
            Text.onClick(() => {
                // showToast('fullscreen clicked');
                /*let currentStatus = this.isFullScreen;
                window.getLastWindow(getContext(this)).then(wind => {
                  wind.setPreferredOrientation( !currentStatus ? window.Orientation.LANDSCAPE : window.Orientation.PORTRAIT);
                  // wind.setWindowSystemBarEnable( !currentStatus ? [] : ['status']);
                  if (this.autoRotateResetTimer !== null) {
                    clearTimeout(this.autoRotateResetTimer);
                    this.autoRotateResetTimer = null;
                  }
                  this.autoRotateResetTimer = setTimeout(() => {
                    this.autoRotateResetTimer = null;
                    wind.setPreferredOrientation(window.Orientation.AUTO_ROTATION);
                  }, 3000);
                });*/
                this.mFullscreenListener?.onFullscreenToggled();
            });
            Text.fontSize(14);
            Text.fontColor('#ffffff');
            Text.width('10%');
            Text.textAlign(TextAlign.Center);
        }, Text);
        Text.pop();
        Row.pop();
        Column.pop();
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            If.create();
            if (this.showLoadingScene) {
                this.ifElseBranchUpdateFunction(0, () => {
                    this.observeComponentCreation2((elmtId, isInitialRender) => {
                        Row.create();
                        Row.width('30%');
                        Row.height('40%');
                        Row.alignItems(VerticalAlign.Center);
                        Row.justifyContent(FlexAlign.Center);
                        Row.margin({ left: '35%', right: '35%', bottom: '15%' });
                    }, Row);
                    this.observeComponentCreation2((elmtId, isInitialRender) => {
                        Column.create();
                        Column.width('100%');
                        Column.justifyContent(FlexAlign.Center);
                        Column.alignItems(HorizontalAlign.Center);
                        Column.height('100%');
                        Column.backgroundColor('rgba(0, 0, 0, 0.7)');
                        Column.borderRadius(5);
                    }, Column);
                    this.observeComponentCreation2((elmtId, isInitialRender) => {
                        Stack.create();
                        Stack.margin({ top: 5 });
                    }, Stack);
                    this.observeComponentCreation2((elmtId, isInitialRender) => {
                        Progress.create({ value: this.loadingProgress, total: 100, type: ProgressType.ScaleRing });
                        Progress.color(Color.Grey);
                        Progress.width(45);
                        Progress.style({ strokeWidth: 8, scaleCount: 20, scaleWidth: 3 });
                    }, Progress);
                    this.observeComponentCreation2((elmtId, isInitialRender) => {
                        Text.create(this.loadingProgress + '%');
                        Text.fontSize(12);
                        Text.fontColor('#FFFFFF');
                    }, Text);
                    Text.pop();
                    Stack.pop();
                    this.observeComponentCreation2((elmtId, isInitialRender) => {
                        Text.create("Loading... " + this.loadingSpeed + "Kb/s");
                        Text.fontSize(12);
                        Text.fontColor('#FFFFFF');
                        Text.margin({ bottom: 10 });
                    }, Text);
                    Text.pop();
                    Column.pop();
                    Row.pop();
                });
            }
            else {
                this.ifElseBranchUpdateFunction(1, () => {
                });
            }
        }, If);
        If.pop();
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            If.create();
            if (this.showFinishScene) {
                this.ifElseBranchUpdateFunction(0, () => {
                    this.observeComponentCreation2((elmtId, isInitialRender) => {
                        Row.create();
                        Row.width('60%');
                        Row.alignItems(VerticalAlign.Center);
                        Row.justifyContent(FlexAlign.Center);
                        Row.margin({ left: '20%', right: '20%' });
                        Row.height('100%');
                    }, Row);
                    this.observeComponentCreation2((elmtId, isInitialRender) => {
                        Column.create();
                        Column.width('100%');
                        Column.justifyContent(FlexAlign.Center);
                        Column.alignItems(HorizontalAlign.Center);
                        Column.height('60%');
                        Column.backgroundColor('rgba(0, 0, 0, 0.7)');
                        Column.borderRadius(5);
                    }, Column);
                    this.observeComponentCreation2((elmtId, isInitialRender) => {
                        Text.create("播放" + (!this.isError ? "结束" : "出错"));
                        Text.fontSize(12);
                        Text.fontColor('#FFFFFF');
                        Text.margin({ bottom: 15 });
                    }, Text);
                    Text.pop();
                    this.observeComponentCreation2((elmtId, isInitialRender) => {
                        Button.createWithLabel((!this.isError ? "重播" : "重试"), { type: ButtonType.Normal, stateEffect: true });
                        Button.fontColor('#4488CC');
                        Button.backgroundColor('rgba(0, 0, 0, 0)');
                        Button.borderRadius(3);
                        Button.borderWidth(1);
                        Button.borderColor('#4488CC');
                        Button.fontSize(12);
                        Button.height(28);
                        Button.onClick(() => {
                            this.showFinishScene = false;
                            this.replaying = true;
                            VideoController.getPlayer(this.playerIndex)?.stop();
                            VideoController.getPlayer(this.playerIndex)?.prepare();
                        });
                        Button.margin({ bottom: 5 });
                    }, Button);
                    Button.pop();
                    this.observeComponentCreation2((elmtId, isInitialRender) => {
                        If.create();
                        if (this.isError) {
                            this.ifElseBranchUpdateFunction(0, () => {
                                this.observeComponentCreation2((elmtId, isInitialRender) => {
                                    Divider.create();
                                    Divider.vertical(false);
                                    Divider.strokeWidth(1);
                                    Divider.color('#FFFFFF');
                                    Divider.margin({ bottom: 2 });
                                }, Divider);
                                this.observeComponentCreation2((elmtId, isInitialRender) => {
                                    Row.create();
                                    Row.width('100%');
                                    Row.alignItems(VerticalAlign.Center);
                                }, Row);
                                this.observeComponentCreation2((elmtId, isInitialRender) => {
                                    Column.create();
                                    Column.width('30%');
                                    Column.alignItems(HorizontalAlign.Start);
                                }, Column);
                                this.observeComponentCreation2((elmtId, isInitialRender) => {
                                    Text.create("Code:");
                                    Text.fontSize(10);
                                    Text.fontColor('#FFFFFF');
                                    Text.margin({ bottom: 3 });
                                }, Text);
                                Text.pop();
                                this.observeComponentCreation2((elmtId, isInitialRender) => {
                                    Text.create("Message:");
                                    Text.fontSize(10);
                                    Text.fontColor('#FFFFFF');
                                    Text.margin({ bottom: 3 });
                                }, Text);
                                Text.pop();
                                Column.pop();
                                this.observeComponentCreation2((elmtId, isInitialRender) => {
                                    Column.create();
                                    Column.width('70%');
                                    Column.alignItems(HorizontalAlign.Start);
                                }, Column);
                                this.observeComponentCreation2((elmtId, isInitialRender) => {
                                    Text.create("" + this.errInfo?.getCode());
                                    Text.fontSize(10);
                                    Text.fontColor('#FFFFFF');
                                    Text.margin({ bottom: 3 });
                                }, Text);
                                Text.pop();
                                this.observeComponentCreation2((elmtId, isInitialRender) => {
                                    Text.create("" + this.errInfo?.getMsg());
                                    Text.fontSize(10);
                                    Text.fontColor('#FFFFFF');
                                    Text.margin({ bottom: 3 });
                                }, Text);
                                Text.pop();
                                Column.pop();
                                Row.pop();
                            });
                        }
                        else {
                            this.ifElseBranchUpdateFunction(1, () => {
                            });
                        }
                    }, If);
                    If.pop();
                    Column.pop();
                    Row.pop();
                });
            }
            else {
                this.ifElseBranchUpdateFunction(1, () => {
                });
            }
        }, If);
        If.pop();
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            If.create();
            if (this.showBrightnessScene) {
                this.ifElseBranchUpdateFunction(0, () => {
                    this.observeComponentCreation2((elmtId, isInitialRender) => {
                        Row.create();
                        Row.width('30%');
                        Row.height('40%');
                        Row.alignItems(VerticalAlign.Center);
                        Row.justifyContent(FlexAlign.Center);
                        Row.margin({ left: '35%', right: '35%', bottom: '15%' });
                    }, Row);
                    this.observeComponentCreation2((elmtId, isInitialRender) => {
                        Column.create();
                        Column.width('100%');
                        Column.justifyContent(FlexAlign.Center);
                        Column.alignItems(HorizontalAlign.Center);
                        Column.height('100%');
                        Column.backgroundColor('rgba(0, 0, 0, 0.7)');
                        Column.borderRadius(5);
                    }, Column);
                    this.observeComponentCreation2((elmtId, isInitialRender) => {
                        Text.create("亮度");
                        Text.fontSize(12);
                        Text.fontColor('#FFFFFF');
                        Text.margin({ bottom: 10 });
                    }, Text);
                    Text.pop();
                    this.observeComponentCreation2((elmtId, isInitialRender) => {
                        Text.create((this.displayBrightness * 100).toFixed(0) + "%");
                        Text.fontSize(12);
                        Text.fontColor('#FFFFFF');
                        Text.margin({ bottom: 10 });
                    }, Text);
                    Text.pop();
                    Column.pop();
                    Row.pop();
                });
            }
            else {
                this.ifElseBranchUpdateFunction(1, () => {
                });
            }
        }, If);
        If.pop();
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            If.create();
            if (this.showVolumeScene) {
                this.ifElseBranchUpdateFunction(0, () => {
                    this.observeComponentCreation2((elmtId, isInitialRender) => {
                        Row.create();
                        Row.width('30%');
                        Row.height('40%');
                        Row.alignItems(VerticalAlign.Center);
                        Row.justifyContent(FlexAlign.Center);
                        Row.margin({ left: '35%', right: '35%', bottom: '15%' });
                    }, Row);
                    this.observeComponentCreation2((elmtId, isInitialRender) => {
                        Column.create();
                        Column.width('100%');
                        Column.justifyContent(FlexAlign.Center);
                        Column.alignItems(HorizontalAlign.Center);
                        Column.height('100%');
                        Column.backgroundColor('rgba(0, 0, 0, 0.7)');
                        Column.borderRadius(5);
                    }, Column);
                    this.observeComponentCreation2((elmtId, isInitialRender) => {
                        Text.create("音量");
                        Text.fontSize(12);
                        Text.fontColor('#FFFFFF');
                        Text.margin({ bottom: 10 });
                    }, Text);
                    Text.pop();
                    this.observeComponentCreation2((elmtId, isInitialRender) => {
                        Text.create((this.displayVolume * 100).toFixed(0) + "%");
                        Text.fontSize(12);
                        Text.fontColor('#FFFFFF');
                        Text.margin({ bottom: 10 });
                    }, Text);
                    Text.pop();
                    Column.pop();
                    Row.pop();
                });
            }
            else {
                this.ifElseBranchUpdateFunction(1, () => {
                });
            }
        }, If);
        If.pop();
        Stack.pop();
    }
    rerender() {
        this.updateDirtyElements();
    }
}
