import bundleManager from "@ohos:bundle.bundleManager";
import type resmgr from "@ohos:resourceManager";
import batteryInfo from "@ohos:batteryInfo";
import connection from "@ohos:net.connection";
import hilog from "@ohos:hilog";
import util from "@ohos:util";
import type { NativeCallExportBase } from './NativeCallExportBase';
import type { BusinessError } from "@ohos:base";
export class ApplicationUtil {
    static sBundleInfo: bundleManager.BundleInfo;
    static sContext: Context;
    static getContext(): Context {
        if (ApplicationUtil.sContext == undefined) {
            throw Error("Context is null, please call aioUtilIns.setContext() with -- import aioUtilIns from '@acpm/aio_util'-- first");
        }
        return ApplicationUtil.sContext;
    }
    static getBundleInfo(): bundleManager.BundleInfo {
        if (ApplicationUtil.sBundleInfo == undefined) {
            ApplicationUtil.sBundleInfo = bundleManager.getBundleInfoForSelfSync(bundleManager.BundleFlag.GET_BUNDLE_INFO_WITH_APPLICATION
                | bundleManager.BundleFlag.GET_BUNDLE_INFO_WITH_SIGNATURE_INFO);
        }
        return ApplicationUtil.sBundleInfo;
    }
    static getApplicationBundleName(): string {
        let info = ApplicationUtil.getBundleInfo();
        if (info != null && info.appInfo != null) {
            return info.appInfo.name;
        }
        return "";
    }
    static getApplicationSignature(): string {
        let info = ApplicationUtil.getBundleInfo();
        if (info != null && info.signatureInfo != null) {
            return info.signatureInfo.fingerprint;
        }
        return "";
    }
    static getApplicationVersion(): string {
        let info = ApplicationUtil.getBundleInfo();
        if (info != null) {
            return info.versionName;
        }
        return "";
    }
    static getApplicationName(): string {
        let info = ApplicationUtil.getBundleInfo();
        if (info != null) {
            let id = ApplicationUtil.getBundleInfo().appInfo.labelId;
            return ApplicationUtil.getContext().resourceManager.getStringSync(id);
        }
        return "";
    }
    static getCacheDir(): string {
        return ApplicationUtil.getContext().cacheDir;
    }
    static getFileDir(): string {
        return ApplicationUtil.getContext().filesDir;
    }
    static getTempDir(): string {
        return ApplicationUtil.getContext().tempDir;
    }
}
class DeviceUtils {
    static getElectricUsage() {
        return batteryInfo.batterySOC;
    }
}
class UUID {
    static generateRandomUUID() {
        return util.generateRandomUUID(false);
    }
}
class NetworkUtils {
    static isNetworkAvailable() {
        return connection.hasDefaultNetSync();
    }
}
class ResourceUtils {
    static getResourceManager(): resmgr.ResourceManager {
        return ApplicationUtil.getContext().resourceManager;
    }
    static readRawTextFile(filePath: string): string {
        try {
            let content = ResourceUtils.getResourceManager().getRawFileContentSync(filePath);
            let result = '';
            for (let i = 0; i < content.length; i++) {
                result += String.fromCharCode(content[i]);
            }
            return result;
        }
        catch (error) {
            let code = (error as BusinessError).code;
            let message = (error as BusinessError).message;
            hilog.error(0x0000, 'aio_util', `getRawFileContentSync failed, error code: ${code}, message: ${message}.`);
            return "";
        }
    }
}
class MetaDataUtils {
    static getMetadataValue(key: string, moduleType: bundleManager.ModuleType): string {
        let bundleInfo = bundleManager.getBundleInfoForSelfSync(bundleManager.BundleFlag.GET_BUNDLE_INFO_WITH_METADATA |
            bundleManager.BundleFlag.GET_BUNDLE_INFO_WITH_HAP_MODULE);
        for (let i = 0; i < bundleInfo.hapModulesInfo.length; i++) {
            if (bundleInfo.hapModulesInfo[i].type != moduleType) {
                continue;
            }
            for (let j = 0; j < bundleInfo.hapModulesInfo[i].metadata.length; j++) {
                if (bundleInfo.hapModulesInfo[i].metadata[j].name == key) {
                    return bundleInfo.hapModulesInfo[i].metadata[j].value;
                }
            }
        }
        return "";
    }
}
export class AioUtil implements NativeCallExportBase {
    getFunctionsBinder(): Map<string, Function> {
        const loadMap = new Map<string, Function>();
        loadMap.set("ApplicationUtil.getApplicationVersion", ApplicationUtil.getApplicationVersion);
        loadMap.set("ApplicationUtil.getApplicationBundleName", ApplicationUtil.getApplicationBundleName);
        loadMap.set("ApplicationUtil.getApplicationSignature", ApplicationUtil.getApplicationSignature);
        loadMap.set("ApplicationUtil.getCacheDir", ApplicationUtil.getCacheDir);
        loadMap.set("ApplicationUtil.getFileDir", ApplicationUtil.getFileDir);
        loadMap.set("ApplicationUtil.getTempDir", ApplicationUtil.getTempDir);
        loadMap.set("ApplicationUtil.getApplicationName", ApplicationUtil.getApplicationName);
        loadMap.set("DeviceUtils.getElectricUsage", DeviceUtils.getElectricUsage);
        loadMap.set("NetworkUtils.isNetworkAvailable", NetworkUtils.isNetworkAvailable);
        loadMap.set("UUID.generateRandomUUID", UUID.generateRandomUUID);
        loadMap.set("ResourceUtils.getResourceManager", ResourceUtils.getResourceManager);
        loadMap.set("ResourceUtils.readRawTextFile", ResourceUtils.readRawTextFile);
        loadMap.set("MetaDataUtils.getMetadataValue", MetaDataUtils.getMetadataValue);
        return loadMap;
    }
    setup(context: Context) {
        ApplicationUtil.sContext = context.getApplicationContext();
    }
}
